use std::net;
use crate::util::error::Error;

pub fn get_addr() -> Result<net::IpAddr, Error> {
    let socket: net::UdpSocket;
    match net::UdpSocket::bind("0.0.0.0:0") {
        Ok(s) => {
            socket = s;
        }

        Err(error) => {
            return Err(
                Error::new(format!("error binding UDP socket: {}", error).as_str())
            );
        }
    }

    match socket.connect("8.8.8.8:80") {
        Ok(()) => {}
        Err(error) => {
            return Err(
                Error::new(format!("could not connect to 8.8.8.8: {}", error).as_str())
            );
        }
    }

    match socket.local_addr() {
        Ok(addr) => {
            return Ok(addr.ip());
        }

        Err(error) => {
            return Err(
                Error::new(format!("could not get local IP address from socket: {}", error).as_str()) 
            );
        }
    }    
}